@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -86,8 +86,15 @@ class CreateCustomJobRequest(proto.Message):
             Required. The CustomJob to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    custom_job = proto.Field(proto.MESSAGE, number=2, message=gca_custom_job.CustomJob,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    custom_job = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gca_custom_job.CustomJob,
+    )
 
 
 class GetCustomJobRequest(proto.Message):
@@ -100,7 +107,10 @@ class GetCustomJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/customJobs/{custom_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCustomJobsRequest(proto.Message):
@@ -142,11 +152,27 @@ class ListCustomJobsRequest(proto.Message):
             Mask specifying which fields to read.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    read_mask = proto.Field(proto.MESSAGE, number=5, message=field_mask_pb2.FieldMask,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    read_mask = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListCustomJobsResponse(proto.Message):
@@ -167,9 +193,14 @@ class ListCustomJobsResponse(proto.Message):
         return self
 
     custom_jobs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_custom_job.CustomJob,
+        proto.MESSAGE,
+        number=1,
+        message=gca_custom_job.CustomJob,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteCustomJobRequest(proto.Message):
@@ -183,7 +214,10 @@ class DeleteCustomJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/customJobs/{custom_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CancelCustomJobRequest(proto.Message):
@@ -196,7 +230,10 @@ class CancelCustomJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/customJobs/{custom_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateDataLabelingJobRequest(proto.Message):
@@ -211,9 +248,14 @@ class CreateDataLabelingJobRequest(proto.Message):
             Required. The DataLabelingJob to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     data_labeling_job = proto.Field(
-        proto.MESSAGE, number=2, message=gca_data_labeling_job.DataLabelingJob,
+        proto.MESSAGE,
+        number=2,
+        message=gca_data_labeling_job.DataLabelingJob,
     )
 
 
@@ -227,7 +269,10 @@ class GetDataLabelingJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/dataLabelingJobs/{data_labeling_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListDataLabelingJobsRequest(proto.Message):
@@ -272,12 +317,31 @@ class ListDataLabelingJobsRequest(proto.Message):
             for descending.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    read_mask = proto.Field(proto.MESSAGE, number=5, message=field_mask_pb2.FieldMask,)
-    order_by = proto.Field(proto.STRING, number=6,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    read_mask = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=field_mask_pb2.FieldMask,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListDataLabelingJobsResponse(proto.Message):
@@ -297,9 +361,14 @@ class ListDataLabelingJobsResponse(proto.Message):
         return self
 
     data_labeling_jobs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_data_labeling_job.DataLabelingJob,
+        proto.MESSAGE,
+        number=1,
+        message=gca_data_labeling_job.DataLabelingJob,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteDataLabelingJobRequest(proto.Message):
@@ -313,7 +382,10 @@ class DeleteDataLabelingJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/dataLabelingJobs/{data_labeling_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CancelDataLabelingJobRequest(proto.Message):
@@ -326,7 +398,10 @@ class CancelDataLabelingJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/dataLabelingJobs/{data_labeling_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateHyperparameterTuningJobRequest(proto.Message):
@@ -343,7 +418,10 @@ class CreateHyperparameterTuningJobRequest(proto.Message):
             create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     hyperparameter_tuning_job = proto.Field(
         proto.MESSAGE,
         number=2,
@@ -362,7 +440,10 @@ class GetHyperparameterTuningJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/hyperparameterTuningJobs/{hyperparameter_tuning_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListHyperparameterTuningJobsRequest(proto.Message):
@@ -404,11 +485,27 @@ class ListHyperparameterTuningJobsRequest(proto.Message):
             Mask specifying which fields to read.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    read_mask = proto.Field(proto.MESSAGE, number=5, message=field_mask_pb2.FieldMask,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    read_mask = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListHyperparameterTuningJobsResponse(proto.Message):
@@ -435,7 +532,10 @@ class ListHyperparameterTuningJobsResponse(proto.Message):
         number=1,
         message=gca_hyperparameter_tuning_job.HyperparameterTuningJob,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteHyperparameterTuningJobRequest(proto.Message):
@@ -449,7 +549,10 @@ class DeleteHyperparameterTuningJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/hyperparameterTuningJobs/{hyperparameter_tuning_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CancelHyperparameterTuningJobRequest(proto.Message):
@@ -463,7 +566,10 @@ class CancelHyperparameterTuningJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/hyperparameterTuningJobs/{hyperparameter_tuning_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateBatchPredictionJobRequest(proto.Message):
@@ -479,9 +585,14 @@ class CreateBatchPredictionJobRequest(proto.Message):
             Required. The BatchPredictionJob to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     batch_prediction_job = proto.Field(
-        proto.MESSAGE, number=2, message=gca_batch_prediction_job.BatchPredictionJob,
+        proto.MESSAGE,
+        number=2,
+        message=gca_batch_prediction_job.BatchPredictionJob,
     )
 
 
@@ -496,7 +607,10 @@ class GetBatchPredictionJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/batchPredictionJobs/{batch_prediction_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListBatchPredictionJobsRequest(proto.Message):
@@ -540,11 +654,27 @@ class ListBatchPredictionJobsRequest(proto.Message):
             Mask specifying which fields to read.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    read_mask = proto.Field(proto.MESSAGE, number=5, message=field_mask_pb2.FieldMask,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    read_mask = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListBatchPredictionJobsResponse(proto.Message):
@@ -566,9 +696,14 @@ class ListBatchPredictionJobsResponse(proto.Message):
         return self
 
     batch_prediction_jobs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_batch_prediction_job.BatchPredictionJob,
+        proto.MESSAGE,
+        number=1,
+        message=gca_batch_prediction_job.BatchPredictionJob,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteBatchPredictionJobRequest(proto.Message):
@@ -582,7 +717,10 @@ class DeleteBatchPredictionJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/batchPredictionJobs/{batch_prediction_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CancelBatchPredictionJobRequest(proto.Message):
@@ -596,7 +734,10 @@ class CancelBatchPredictionJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/batchPredictionJobs/{batch_prediction_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateModelDeploymentMonitoringJobRequest(proto.Message):
@@ -612,7 +753,10 @@ class CreateModelDeploymentMonitoringJobRequest(proto.Message):
             create
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     model_deployment_monitoring_job = proto.Field(
         proto.MESSAGE,
         number=2,
@@ -678,18 +822,46 @@ class SearchModelDeploymentMonitoringStatsAnomaliesRequest(proto.Message):
             number=1,
             enum=gca_model_deployment_monitoring_job.ModelDeploymentMonitoringObjectiveType,
         )
-        top_feature_count = proto.Field(proto.INT32, number=4,)
+        top_feature_count = proto.Field(
+            proto.INT32,
+            number=4,
+        )
 
-    model_deployment_monitoring_job = proto.Field(proto.STRING, number=1,)
-    deployed_model_id = proto.Field(proto.STRING, number=2,)
-    feature_display_name = proto.Field(proto.STRING, number=3,)
+    model_deployment_monitoring_job = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    deployed_model_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    feature_display_name = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     objectives = proto.RepeatedField(
-        proto.MESSAGE, number=4, message=StatsAnomaliesObjective,
+        proto.MESSAGE,
+        number=4,
+        message=StatsAnomaliesObjective,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=5,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
     )
-    page_size = proto.Field(proto.INT32, number=5,)
-    page_token = proto.Field(proto.STRING, number=6,)
-    start_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
 
 
 class SearchModelDeploymentMonitoringStatsAnomaliesResponse(proto.Message):
@@ -717,7 +889,10 @@ class SearchModelDeploymentMonitoringStatsAnomaliesResponse(proto.Message):
         number=1,
         message=gca_model_deployment_monitoring_job.ModelMonitoringStatsAnomalies,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetModelDeploymentMonitoringJobRequest(proto.Message):
@@ -731,7 +906,10 @@ class GetModelDeploymentMonitoringJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListModelDeploymentMonitoringJobsRequest(proto.Message):
@@ -752,11 +930,27 @@ class ListModelDeploymentMonitoringJobsRequest(proto.Message):
             Mask specifying which fields to read
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    read_mask = proto.Field(proto.MESSAGE, number=5, message=field_mask_pb2.FieldMask,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    read_mask = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListModelDeploymentMonitoringJobsResponse(proto.Message):
@@ -780,7 +974,10 @@ class ListModelDeploymentMonitoringJobsResponse(proto.Message):
         number=1,
         message=gca_model_deployment_monitoring_job.ModelDeploymentMonitoringJob,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class UpdateModelDeploymentMonitoringJobRequest(proto.Message):
@@ -826,7 +1023,9 @@ class UpdateModelDeploymentMonitoringJobRequest(proto.Message):
         message=gca_model_deployment_monitoring_job.ModelDeploymentMonitoringJob,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -841,7 +1040,10 @@ class DeleteModelDeploymentMonitoringJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class PauseModelDeploymentMonitoringJobRequest(proto.Message):
@@ -855,7 +1057,10 @@ class PauseModelDeploymentMonitoringJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ResumeModelDeploymentMonitoringJobRequest(proto.Message):
@@ -869,7 +1074,10 @@ class ResumeModelDeploymentMonitoringJobRequest(proto.Message):
             ``projects/{project}/locations/{location}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateModelDeploymentMonitoringJobOperationMetadata(proto.Message):
@@ -882,7 +1090,9 @@ class UpdateModelDeploymentMonitoringJobOperationMetadata(proto.Message):
     """
 
     generic_metadata = proto.Field(
-        proto.MESSAGE, number=1, message=operation.GenericOperationMetadata,
+        proto.MESSAGE,
+        number=1,
+        message=operation.GenericOperationMetadata,
     )
 
 
