@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -255,14 +255,13 @@ class PipelineServiceAsyncClient:
         r"""Creates a TrainingPipeline. A created
         TrainingPipeline right away will be attempted to be run.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_create_training_pipeline():
+            async def sample_create_training_pipeline():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 training_pipeline = aiplatform_v1beta1.TrainingPipeline()
@@ -276,7 +275,7 @@ class PipelineServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_training_pipeline(request=request)
+                response = await client.create_training_pipeline(request=request)
 
                 # Handle the response
                 print(response)
@@ -350,7 +349,12 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -366,13 +370,13 @@ class PipelineServiceAsyncClient:
     ) -> training_pipeline.TrainingPipeline:
         r"""Gets a TrainingPipeline.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_get_training_pipeline():
+            async def sample_get_training_pipeline():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.GetTrainingPipelineRequest(
@@ -380,7 +384,7 @@ class PipelineServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_training_pipeline(request=request)
+                response = await client.get_training_pipeline(request=request)
 
                 # Handle the response
                 print(response)
@@ -445,7 +449,12 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -461,13 +470,13 @@ class PipelineServiceAsyncClient:
     ) -> pagers.ListTrainingPipelinesAsyncPager:
         r"""Lists TrainingPipelines in a Location.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_list_training_pipelines():
+            async def sample_list_training_pipelines():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.ListTrainingPipelinesRequest(
@@ -478,7 +487,7 @@ class PipelineServiceAsyncClient:
                 page_result = client.list_training_pipelines(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -540,12 +549,20 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListTrainingPipelinesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -562,13 +579,13 @@ class PipelineServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a TrainingPipeline.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_delete_training_pipeline():
+            async def sample_delete_training_pipeline():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.DeleteTrainingPipelineRequest(
@@ -580,7 +597,7 @@ class PipelineServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -654,7 +671,12 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -690,14 +712,13 @@ class PipelineServiceAsyncClient:
         [TrainingPipeline.state][google.cloud.aiplatform.v1beta1.TrainingPipeline.state]
         is set to ``CANCELLED``.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_cancel_training_pipeline():
+            async def sample_cancel_training_pipeline():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.CancelTrainingPipelineRequest(
@@ -705,7 +726,7 @@ class PipelineServiceAsyncClient:
                 )
 
                 # Make the request
-                client.cancel_training_pipeline(request=request)
+                await client.cancel_training_pipeline(request=request)
 
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CancelTrainingPipelineRequest, dict]):
@@ -758,7 +779,10 @@ class PipelineServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def create_pipeline_job(
@@ -775,14 +799,13 @@ class PipelineServiceAsyncClient:
         r"""Creates a PipelineJob. A PipelineJob will run
         immediately when created.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_create_pipeline_job():
+            async def sample_create_pipeline_job():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.CreatePipelineJobRequest(
@@ -790,7 +813,7 @@ class PipelineServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_pipeline_job(request=request)
+                response = await client.create_pipeline_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -871,7 +894,12 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -887,13 +915,13 @@ class PipelineServiceAsyncClient:
     ) -> pipeline_job.PipelineJob:
         r"""Gets a PipelineJob.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_get_pipeline_job():
+            async def sample_get_pipeline_job():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.GetPipelineJobRequest(
@@ -901,7 +929,7 @@ class PipelineServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_pipeline_job(request=request)
+                response = await client.get_pipeline_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -961,7 +989,12 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -977,13 +1010,13 @@ class PipelineServiceAsyncClient:
     ) -> pagers.ListPipelineJobsAsyncPager:
         r"""Lists PipelineJobs in a Location.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_list_pipeline_jobs():
+            async def sample_list_pipeline_jobs():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.ListPipelineJobsRequest(
@@ -994,7 +1027,7 @@ class PipelineServiceAsyncClient:
                 page_result = client.list_pipeline_jobs(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1056,12 +1089,20 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListPipelineJobsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1078,13 +1119,13 @@ class PipelineServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a PipelineJob.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_delete_pipeline_job():
+            async def sample_delete_pipeline_job():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.DeletePipelineJobRequest(
@@ -1096,7 +1137,7 @@ class PipelineServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1170,7 +1211,12 @@ class PipelineServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1206,14 +1252,13 @@ class PipelineServiceAsyncClient:
         [PipelineJob.state][google.cloud.aiplatform.v1beta1.PipelineJob.state]
         is set to ``CANCELLED``.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_cancel_pipeline_job():
+            async def sample_cancel_pipeline_job():
                 # Create a client
-                client = aiplatform_v1beta1.PipelineServiceClient()
+                client = aiplatform_v1beta1.PipelineServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.CancelPipelineJobRequest(
@@ -1221,7 +1266,7 @@ class PipelineServiceAsyncClient:
                 )
 
                 # Make the request
-                client.cancel_pipeline_job(request=request)
+                await client.cancel_pipeline_job(request=request)
 
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CancelPipelineJobRequest, dict]):
@@ -1273,7 +1318,10 @@ class PipelineServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def __aenter__(self):
